import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:android_broadcaster/android_broadcaster.dart';

void main() {
  AndroidBroadcaster.initialize(_handlerBackgroundMethod);
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _platformVersion = 'Unknown';

  @override
  void initState() {
    super.initState();
    initPlatformState();
    AndroidBroadcaster.startBroadcastReceiver(action: "com.example.android_broadcaster",onReceive: _onReceived);
  }

  @override
  dispose(){
    AndroidBroadcaster.stopBroadcastReceiver(action: "com.example.android_broadcaster",);
    super.dispose();
  }

  // Platform messages are asynchronous, so we initialize in an async method.
  Future<void> initPlatformState() async {
    String platformVersion;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      platformVersion = await AndroidBroadcaster.platformVersion;
    } on PlatformException {
      platformVersion = 'Failed to get platform version.';
    }

    // If the widget was removed from the tree while the asynchronous platform
    // message was in flight, we want to discard the reply rather than calling
    // setState to update our non-existent appearance.
    if (!mounted) return;

    setState(() {
      _platformVersion = platformVersion;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: GestureDetector(
        onDoubleTap: (){
          AndroidBroadcaster.broadcastEvent(action: "com.example.android_broadcaster", data: "this is data");
        },
        child: Scaffold(
          appBar: AppBar(
            title: const Text('Plugin example app'),
          ),
          body: Center(
            child: Text('Running on: $_platformVersion\n'),
          ),
        ),
      ),
    );
  }

  _onReceived(String data) {
    print(data);
  }
}

_handlerBackgroundMethod(data) {
  print("*** Message Received from :$data");
  WidgetsFlutterBinding.ensureInitialized();
  AndroidBroadcaster.broadcastEvent(
    action:"com.example.broadcastsenderapp.event",
    data:"this is data",
  );

}
