
import 'dart:async';
import 'dart:io';
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
class AndroidBroadcaster {
  static const MethodChannel _channel = const MethodChannel('com.rouf69nb.android_broadcaster');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static void initialize(Function(dynamic data) handler) {
    if (Platform.isAndroid) {
      WidgetsFlutterBinding.ensureInitialized();
      const MethodChannel channel = MethodChannel('com.rouf69nb.android_broadcaster');
      final CallbackHandle callback = PluginUtilities.getCallbackHandle(handler);
      final handle = callback.toRawHandle();
      channel.invokeMethod('initialize', handle);
    }
  }

  static void broadcastEvent({@required String action, @required String data}){
    _channel.invokeMethod("broadcastEvent",<String,String>{
      "action":action,
      "data":data,
    }).then((_){}).catchError((e){
      print(e);
    });
  }

  static void startBroadcastReceiver({@required String action,@required Function(String data) onReceive}){
    _channel.invokeMethod("startInstanceReceiver",action).then((_){
      _channel.setMethodCallHandler((call){
        if(call.method == "eventReceived"){
          onReceive?.call(call.arguments);
        }
        return;
      });
    }).catchError((e){
      print(e);
    });
  }

  static void stopBroadcastReceiver({@required String action,}){
    _channel.invokeMethod("stopInstanceReceiver",action).then((_){}).catchError((e){
      print(e);
    });
  }



}

